==> multiple-file-picker-component-0.0.32.tgz: package/src/MultipleFilePickerComponent.tsx <==
import {
  Box,
  Text,
  FormControl,
  Icon,
  Image,
  Progress,
  Flex,
  IconButton,
  Modal,
  ModalOverlay,
  ModalContent,
  ModalBody,
  ModalFooter,
  Button,
} from "@chakra-ui/react";
import { FileError, useDropzone } from "react-dropzone";
import React from "react";
import { Upload, Delete, Movie, FileBlank } from "@feedloop/icon";
import { useSource } from "@qorebase/app-runtime/src/hooks/useSource";
import produce from "immer";
import { useFormSubmitHook } from "@qorebase/app-runtime/src/hooks/useFormSubmitHook";
import {
  RuntimeContext,
  RuntimeInputContext,
  useDisableCondition,
  useTemplate,
  useClient,
  useStorageToken,
} from "@qorebase/app-component";
import { fallbackImg } from "@qorebase/app-runtime/src/utils/fallbackImage";
import InputComponentFormLabel from "@qorebase/app-runtime/src/components/InputComponentFormLabel";
import { MultipleFilePickerComponentType } from "./multipleFilePicker";

export interface RejectedFiles {
  file: File;
  errors: FileError[];
}

type FileMetadata = {
  mimetype: string;
  filename: string;
  size: number;
};

export type CropProps = {
  unit: string;
  height: number;
  aspect: number;
};

export interface FileUpload {
  file: File;
  uploaded: boolean;
}

const MultipleFilePickerComponent: MultipleFilePickerComponentType = (
  props
) => {
  const title = useTemplate(props.properties.label);
  const placeholder = useTemplate(props.properties.placeholder);
  const fileSize = 4000000;
  const maxFileSizeText =
    "Maximum File Size: " + `${fileSize / 1000000}` + "MB";
  const [state, setState] = React.useState<{
    files: Record<string, FileUpload>;
    loaded: number;
    total: number;
  }>({ files: {}, loaded: 0, total: 0 });
  const [filesToDelete, setFilesToDelete] = React.useState<FileMetadata[]>([]);

  const client = useClient();
  const source = useSource();

  const tables = RuntimeContext.useSelectState(
    (state) => state.app.schema.tables
  );
  const views = RuntimeContext.useSelectState(
    (state) => state.app.schema.views
  );
  const tableName = React.useMemo(
    () =>
      tables.find((t) => t.name === source.target)?.name ||
      views.find((v) => v.name === source.target)?.query.table,
    [tables, views, source.target]
  );
  const column = props.properties.data.inputID;
  const tableData = React.useMemo(() => {
    const tableIndex = tables?.findIndex((i) => i.name === tableName);
    return tables[tableIndex] ? tables[tableIndex].columns : [];
  }, [tables, tableName]);
  const extension = React.useMemo(() => {
    const columnIndex = tableData?.findIndex((i) => i.name === column);
    return tableData[columnIndex]?.type === "multiple_files" ||
      tableData[columnIndex]?.type === "file"
      ? tableData[columnIndex].definition.extensions
      : "";
  }, [tableData, column]);

  useFormSubmitHook(
    async (row) => {
      if (Object.keys(state.files).length > 0) {
        const uploadToken = await client.project.axios({
          baseURL: client.project.config.endpoint,
          url: `/v1/files/token/table/${tableName}/id/${row.id}/column/${column}?access=write`,
          method: "GET",
        });
        const formData = new FormData();
        for (const file of Object.values(state.files)) {
          formData.append(file.file.name, file.file);
        }
        await client.project.axios.post(
          `/v1/multiple_files/upload?token=${uploadToken.data.token}`,
          formData,
          {
            baseURL: client.project.config.endpoint,
            headers: {
              "Content-Type": "multipart/form-data",
            },
            onUploadProgress: (event: ProgressEvent) => {
              setState((state) =>
                produce(state, (draft) => {
                  draft.loaded = event.loaded;
                  draft.total = event.total;
                })
              );
            },
          }
        );
      }
      if (filesToDelete.length > 0) {
        await Promise.all(
          filesToDelete.map(async (file) => {
            const deleteToken = await client.project.axios({
              baseURL: client.project.config.endpoint,
              url: `/v1/files/token/table/${tableName}/id/${row.id}/column/${column}?access=delete`,
              method: "GET",
            });
            return client.project.axios.delete(
              `/v1/files/${file.filename}?token=${deleteToken.data.token}`,
              {
                baseURL: client.project.config.endpoint,
              }
            );
          })
        );
      }
    },
    [tableName, column, state.files, filesToDelete]
  );

  const storageToken = useStorageToken();
  const getURL = (file: { filename: string; url?: string }) => {
    return storageToken && "url" in file
      ? `${file.url}?token=${storageToken}`
      : `${client.project.config.endpoint}/v1/files/public/${tableName}/${props.data.page.row.id}/${column}/${file.filename}`;
  };
  const handleFileReader = (file: File) => {
    const reader = new FileReader();
    reader.onload = (e) => {
      Promise.resolve(e.target.result as string).then((value) => {
        setState((prev) => ({ ...prev }));
        file["data"] = value;
      });
    };
    reader.readAsDataURL(file);
  };
  const onDrop = React.useCallback(
    async (files: File[]) => {
      files.forEach(function (x) {
        handleFileReader(x);
      });
      setState((state) =>
        produce(state, (draft) => {
          for (const file of files) {
            draft.files[file.name] = { file, uploaded: false };
          }
        })
      );
    },
    [source, column]
  );

  const { getRootProps, getInputProps } = useDropzone({
    onDrop,
    multiple: true,
    accept: extension,
  });

  const paddingSpace = {
    paddingTop: 10,
    maxWidth: "100%",
  };

  const uploadedFiles = React.useMemo(
    () =>
      (
        (props.data.page.row[props.properties.data.inputID] ||
          []) as FileMetadata[]
      ).filter(
        (file) =>
          !filesToDelete.find(
            (fileToDelete) => fileToDelete.filename === file.filename
          )
      ),
    [props.data.page.row[props.properties.data.inputID], filesToDelete]
  );
  const filesToUpload = React.useMemo(
    () => Object.values(state.files),
    [state.files]
  );
  const inputActions = RuntimeInputContext.useActions();

  const [validationMessage, setValidationMessage] = React.useState("");
  const isRequired = props.properties.data.validation?.required;
  React.useEffect(() => {
    const totalFiles = uploadedFiles.length + filesToUpload.length;
    if (isRequired && totalFiles === 0) {
      const message = `${title} require at least one file.`;
      inputActions.setValidation({
        [column]: { error: message },
      });
      setValidationMessage(message);
    } else {
      inputActions.setValidation({
        [column]: undefined,
      });
      setValidationMessage("");
    }
  }, [uploadedFiles, filesToUpload, isRequired]);

  const arrSize = Object.keys(state.files).length;
  const currFileSize = Object.values(state.files)[arrSize - 1]?.file.size;
  // @ts-ignore
  const { isDisabled } = useDisableCondition(props.instance);
  return (
    <Box display={props.properties.hidden ? "none" : undefined}>
      <FormControl>
        <InputComponentFormLabel
          title={title}
          name="multiple-file-picker"
          instanceId={props.instance.id}
          fontWeight="normal"
          isRequired={props.properties.data.validation?.required}
          isEmpty={title.length === 0}
        />
        {!!uploadedFiles.length && (
          <Box
            mt={2}
            border="1px"
            borderRadius="md"
            borderColor="surface.900"
            paddingY="5"
            paddingX="3"
          >
            <Box mb={2}>
              <Text fontWeight={"semibold"}>Uploaded files</Text>
            </Box>
            {uploadedFiles.map((file) => (
              <Flex key={file.filename} alignItems="center">
                <Box
                  display="flex"
                  width="48px"
                  height="48px"
                  bgColor={`${props.app.theme.options.primaryColor}23`}
                  marginRight={5}
                  justifyContent="center"
                  alignItems="center"
                  borderRadius="4px"
                  marginTop={2}
                >
                  {file.mimetype.startsWith("image") ? (
                    <Image
                      alt="New image"
                      src={getURL(file) ?? fallbackImg}
                      width="48px"
                      height="48px"
                      borderRadius="4px"
                    />
                  ) : file.mimetype.startsWith("video") ? (
                    <Icon
                      as={Movie}
                      boxSize={7}
                      color={`${props.app.theme.options.primaryColor}`}
                    />
                  ) : file.mimetype === "application/pdf" ? (
                    <Icon
                      as={FileBlank}
                      boxSize={7}
                      color={`${props.app.theme.options.primaryColor}`}
                    />
                  ) : (
                    <Icon
                      as={Upload}
                      boxSize={7}
                      color={`${props.app.theme.options.primaryColor}`}
                    />
                  )}
                </Box>
                <Box flex={1}>
                  <Text noOfLines={1}>{file.filename}</Text>
                  <Text fontSize="sm" textColor="text.600">
                    {Math.ceil(file.size / 1024)} KB
                  </Text>
                </Box>
                <IconButton
                  aria-label="delete file"
                  icon={<Icon as={Delete} />}
                  variant="link"
                  color="#171717"
                  _hover={{ color: "#E03138", bg: "#FCEAEB" }}
                  width="48px"
                  height="48px"
                  onClick={() =>
                    setFilesToDelete((files) => files.concat(file))
                  }
                />
              </Flex>
            ))}
          </Box>
        )}

        {/* Modal Max upload validation */}
        <Modal
          isOpen={currFileSize > fileSize}
          isCentered
          size="xs"
          onClose={() => {}}
        >
          <ModalOverlay />
          <ModalContent paddingY="5">
            <ModalBody>
              <Text textAlign="center" fontSize="xl" fontWeight="bold">
                Sorry, file size is too big
              </Text>
              <Text textAlign="center" fontSize="sm" color="blackAlpha.500">
                {maxFileSizeText}
              </Text>
            </ModalBody>
            <ModalFooter>
              <Button
                onClick={() => setState((prev) => ({ ...prev, files: {} }))}
                w="full"
              >
                Ok
              </Button>
            </ModalFooter>
          </ModalContent>
        </Modal>
        {!!filesToUpload.length && (
          <Box
            mt={2}
            border="1px"
            borderRadius="md"
            borderColor="surface.900"
            paddingY="5"
            paddingX="3"
          >
            <Box mb={2}>
              <Text fontWeight={"semibold"}>Files to upload</Text>
            </Box>
            {filesToUpload.map((file) => (
              <Flex key={file.file.name} alignItems="center">
                <Box
                  display="flex"
                  width="48px"
                  height="48px"
                  bgColor={`${props.app.theme.options.primaryColor}23`}
                  marginRight={5}
                  justifyContent="center"
                  alignItems="center"
                  borderRadius="4px"
                  marginTop={2}
                >
                  {file.file.type.startsWith("image") ? (
                    <Image
                      alt="New image"
                      src={file.file["data"] ?? fallbackImg}
                      width="48px"
                      height="48px"
                      borderRadius="4px"
                    />
                  ) : file.file.type.startsWith("video") ? (
                    <Icon
                      as={Movie}
                      boxSize={7}
                      color={`${props.app.theme.options.primaryColor}`}
                    />
                  ) : file.file.type === "application/pdf" ? (
                    <Icon
                      as={FileBlank}
                      boxSize={7}
                      color={`${props.app.theme.options.primaryColor}`}
                    />
                  ) : (
                    <Icon
                      as={Upload}
                      boxSize={7}
                      color={`${props.app.theme.options.primaryColor}`}
                    />
                  )}
                </Box>
                <Box flex={1}>
                  <Text noOfLines={1}>{file.file.name}</Text>
                  <Text fontSize="sm" textColor="text.600">
                    {Math.ceil(file.file.size / 1024)} KB
                  </Text>
                </Box>
                <IconButton
                  aria-label="delete file"
                  icon={<Icon as={Delete} />}
                  variant="link"
                  color="#171717"
                  _hover={{ color: "#E03138", bg: "#FCEAEB" }}
                  width="48px"
                  height="48px"
                  onClick={() => {
                    setState((state) => ({
                      ...state,
                      files: Object.fromEntries(
                        Object.entries(state.files).filter(
                          ([key]) => key !== file.file.name
                        )
                      ),
                    }));
                  }}
                />
              </Flex>
            ))}
            {!!state.total && (
              <>
                <Progress
                  value={Math.round((state.loaded / state.total) * 100)}
                />
                <Text fontSize="sm" textColor="blackAlpha.600">
                  {Math.ceil(state.loaded / 1024)}/
                  {Math.ceil(state.total / 1024)} KB
                </Text>
              </>
            )}
          </Box>
        )}

        <Box
          {...getRootProps({ className: "dropzone" })}
          display="flex"
          flexDirection="column"
          alignItems="center"
          mt={2}
          cursor="pointer"
          border="1px"
          borderRadius="md"
          borderColor="rgb(226, 232, 240)"
          paddingY="10"
          bgColor="surface.900"
          style={{
            border: "1px solid rgb(226, 232, 240)",
            pointerEvents: isDisabled ? "none" : "auto",
            background: isDisabled && "#E7E7E7",
            color: isDisabled && "#A2A2A2",
          }}
        >
          <input
            {...getInputProps()}
            key={props.properties.data.inputID}
            name={props.properties.data.inputID}
            capture={
              props.properties.fileType === "camera"
                ? "user" || "environment"
                : undefined
            }
            data-test="file-picker-input"
          />
          <Icon
            as={Upload}
            boxSize={10}
            color={isDisabled ? "#A2A2A2" : "blue.500"}
            data-test="file-picker-input-icon"
          />
          <Text
            style={paddingSpace}
            noOfLines={1}
            align="center"
            w={{ base: "300px", md: "500px" }}
            color={isDisabled && "#A2A2A2"}
          >
            {placeholder}
          </Text>
          <Text fontSize="sm" color="text.600">
            Support for a single and bulk upload.
          </Text>
          <Text fontSize="sm" color="text.600">
            {maxFileSizeText}
          </Text>
        </Box>
      </FormControl>
      {!!validationMessage && (
        <Text fontSize="sm" color="red" mt="2">
          {validationMessage}
        </Text>
      )}
    </Box>
  );
};

export default MultipleFilePickerComponent;

==> multiple-file-picker-component-0.0.37.tgz: package/src/MultipleFilePickerComponent.tsx <==
import {
  Box,
  Text,
  FormControl,
  Icon,
  Image,
  Progress,
  Flex,
  IconButton,
  Modal,
  ModalOverlay,
  ModalContent,
  ModalBody,
  ModalFooter,
  Button,
} from "@chakra-ui/react";
import { FileError, useDropzone } from "react-dropzone";
import React from "react";
import { Upload, Delete, Movie, FileBlank } from "@feedloop/icon";
import { useSource } from "@qorebase/app-runtime/src/hooks/useSource";
import produce from "immer";
import { useFormSubmitHook } from "@qorebase/app-runtime/src/hooks/useFormSubmitHook";
import {
  RuntimeContext,
  RuntimeInputContext,
  useDisableCondition,
  useTemplate,
  useClient,
  useStorageToken,
} from "@qorebase/app-component";
import { fallbackImg } from "@qorebase/app-runtime/src/utils/fallbackImage";
import InputComponentFormLabel from "@qorebase/app-runtime/src/components/InputComponentFormLabel";
import { MultipleFilePickerComponentType } from "./multipleFilePicker";

export interface RejectedFiles {
  file: File;
  errors: FileError[];
}

type FileMetadata = {
  mimetype: string;
  filename: string;
  size: number;
};

export type CropProps = {
  unit: string;
  height: number;
  aspect: number;
};

export interface FileUpload {
  file: File;
  uploaded: boolean;
}

const MultipleFilePickerComponent: MultipleFilePickerComponentType = (
  props
) => {
  const title = useTemplate(props.properties.label);
  const placeholder = useTemplate(props.properties.placeholder);
  const fileSize = 4000000;
  const maxFileSizeText =
    "Maximum File Size: " + `${fileSize / 1000000}` + "MB";
  const [state, setState] = React.useState<{
    files: Record<string, FileUpload>;
    loaded: number;
    total: number;
  }>({ files: {}, loaded: 0, total: 0 });
  const [filesToDelete, setFilesToDelete] = React.useState<FileMetadata[]>([]);

  const client = useClient();
  const source = useSource();

  const tables = RuntimeContext.useSelectState((state) => state.schema.tables);
  const views = RuntimeContext.useSelectState((state) => state.schema.views);
  const tableName = React.useMemo(
    () =>
      tables.find((t) => t.name === source.target)?.name ||
      views.find((v) => v.name === source.target)?.query.table,
    [tables, views, source.target]
  );
  const column = props.properties.data.inputID;
  const tableData = React.useMemo(() => {
    const tableIndex = tables?.findIndex((i) => i.name === tableName);
    return tables[tableIndex] ? tables[tableIndex].columns : [];
  }, [tables, tableName]);
  const extension = React.useMemo(() => {
    const columnIndex = tableData?.findIndex((i) => i.name === column);
    return tableData[columnIndex]?.type === "multiple_files" ||
      tableData[columnIndex]?.type === "file"
      ? tableData[columnIndex].definition.extensions
      : "";
  }, [tableData, column]);

  useFormSubmitHook(
    async (row) => {
      if (Object.keys(state.files).length > 0) {
        const uploadToken = await client.project.axios({
          baseURL: client.project.config.endpoint,
          url: `/v1/files/token/table/${tableName}/id/${row.id}/column/${column}?access=write`,
          method: "GET",
        });
        const formData = new FormData();
        for (const file of Object.values(state.files)) {
          formData.append(file.file.name, file.file);
        }
        await client.project.axios.post(
          `/v1/multiple_files/upload?token=${uploadToken.data.token}`,
          formData,
          {
            baseURL: client.project.config.endpoint,
            headers: {
              "Content-Type": "multipart/form-data",
            },
            onUploadProgress: (event: ProgressEvent) => {
              setState((state) =>
                produce(state, (draft) => {
                  draft.loaded = event.loaded;
                  draft.total = event.total;
                })
              );
            },
          }
        );
      }
      if (filesToDelete.length > 0) {
        await Promise.all(
          filesToDelete.map(async (file) => {
            const deleteToken = await client.project.axios({
              baseURL: client.project.config.endpoint,
              url: `/v1/files/token/table/${tableName}/id/${row.id}/column/${column}?access=delete`,
              method: "GET",
            });
            return client.project.axios.delete(
              `/v1/files/${file.filename}?token=${deleteToken.data.token}`,
              {
                baseURL: client.project.config.endpoint,
              }
            );
          })
        );
      }
    },
    [tableName, column, state.files, filesToDelete]
  );

  const storageToken = useStorageToken();
  const getURL = (file: { filename: string; url?: string }) => {
    return storageToken && "url" in file
      ? `${file.url}?token=${storageToken}`
      : `${client.project.config.endpoint}/v1/files/public/${tableName}/${props.data.page.row.id}/${column}/${file.filename}`;
  };
  const handleFileReader = (file: File) => {
    const reader = new FileReader();
    reader.onload = (e) => {
      Promise.resolve(e.target.result as string).then((value) => {
        setState((prev) => ({ ...prev }));
        file["data"] = value;
      });
    };
    reader.readAsDataURL(file);
  };
  const onDrop = React.useCallback(
    async (files: File[]) => {
      files.forEach(function (x) {
        handleFileReader(x);
      });
      setState((state) =>
        produce(state, (draft) => {
          for (const file of files) {
            draft.files[file.name] = { file, uploaded: false };
          }
        })
      );
    },
    [source, column]
  );

  const { getRootProps, getInputProps } = useDropzone({
    onDrop,
    multiple: true,
    accept: extension,
  });

  const paddingSpace = {
    paddingTop: 10,
    maxWidth: "100%",
  };

  const uploadedFiles = React.useMemo(
    () =>
      (
        (props.data.page.row[props.properties.data.inputID] ||
          []) as FileMetadata[]
      ).filter(
        (file) =>
          !filesToDelete.find(
            (fileToDelete) => fileToDelete.filename === file.filename
          )
      ),
    [props.data.page.row[props.properties.data.inputID], filesToDelete]
  );
  const filesToUpload = React.useMemo(
    () => Object.values(state.files),
    [state.files]
  );
  const inputActions = RuntimeInputContext.useActions();

  const [validationMessage, setValidationMessage] = React.useState("");
  const isRequired = props.properties.data.validation?.required;
  React.useEffect(() => {
    const totalFiles = uploadedFiles.length + filesToUpload.length;
    if (isRequired && totalFiles === 0) {
      const message = `${title} require at least one file.`;
      inputActions.setValidation({
        [column]: { error: message },
      });
      setValidationMessage(message);
    } else {
      inputActions.setValidation({
        [column]: undefined,
      });
      setValidationMessage("");
    }
  }, [uploadedFiles, filesToUpload, isRequired]);

  const arrSize = Object.keys(state.files).length;
  const currFileSize = Object.values(state.files)[arrSize - 1]?.file.size;
  // @ts-ignore
  const { isDisabled } = useDisableCondition(props.instance);
  return (
    <Box display={props.properties.hidden ? "none" : undefined}>
      <FormControl>
        <InputComponentFormLabel
          title={title}
          name="multiple-file-picker"
          instanceId={props.instance.id}
          fontWeight="normal"
          isRequired={props.properties.data.validation?.required}
          isEmpty={title.length === 0}
        />
        {!!uploadedFiles.length && (
          <Box
            mt={2}
            border="1px"
            borderRadius="md"
            borderColor="surface.900"
            paddingY="5"
            paddingX="3"
          >
            <Box mb={2}>
              <Text fontWeight={"semibold"}>Uploaded files</Text>
            </Box>
            {uploadedFiles.map((file) => (
              <Flex key={file.filename} alignItems="center">
                <Box
                  display="flex"
                  width="48px"
                  height="48px"
                  bgColor={`${props.app.theme.options.primaryColor}23`}
                  marginRight={5}
                  justifyContent="center"
                  alignItems="center"
                  borderRadius="4px"
                  marginTop={2}
                >
                  {file.mimetype.startsWith("image") ? (
                    <Image
                      alt="New image"
                      src={getURL(file) ?? fallbackImg}
                      width="48px"
                      height="48px"
                      borderRadius="4px"
                    />
                  ) : file.mimetype.startsWith("video") ? (
                    <Icon
                      as={Movie}
                      boxSize={7}
                      color={`${props.app.theme.options.primaryColor}`}
                    />
                  ) : file.mimetype === "application/pdf" ? (
                    <Icon
                      as={FileBlank}
                      boxSize={7}
                      color={`${props.app.theme.options.primaryColor}`}
                    />
                  ) : (
                    <Icon
                      as={Upload}
                      boxSize={7}
                      color={`${props.app.theme.options.primaryColor}`}
                    />
                  )}
                </Box>
                <Box flex={1}>
                  <Text noOfLines={1}>{file.filename}</Text>
                  <Text fontSize="sm" textColor="text.600">
                    {Math.ceil(file.size / 1024)} KB
                  </Text>
                </Box>
                <IconButton
                  aria-label="delete file"
                  icon={<Icon as={Delete} />}
                  variant="link"
                  color="#171717"
                  _hover={{ color: "#E03138", bg: "#FCEAEB" }}
                  width="48px"
                  height="48px"
                  onClick={() =>
                    setFilesToDelete((files) => files.concat(file))
                  }
                />
              </Flex>
            ))}
          </Box>
        )}

        {/* Modal Max upload validation */}
        <Modal
          isOpen={currFileSize > fileSize}
          isCentered
          size="xs"
          onClose={() => {}}
        >
          <ModalOverlay />
          <ModalContent paddingY="5">
            <ModalBody>
              <Text textAlign="center" fontSize="xl" fontWeight="bold">
                Sorry, file size is too big
              </Text>
              <Text textAlign="center" fontSize="sm" color="blackAlpha.500">
                {maxFileSizeText}
              </Text>
            </ModalBody>
            <ModalFooter>
              <Button
                onClick={() => setState((prev) => ({ ...prev, files: {} }))}
                w="full"
              >
                Ok
              </Button>
            </ModalFooter>
          </ModalContent>
        </Modal>
        {!!filesToUpload.length && (
          <Box
            mt={2}
            border="1px"
            borderRadius="md"
            borderColor="surface.900"
            paddingY="5"
            paddingX="3"
          >
            <Box mb={2}>
              <Text fontWeight={"semibold"}>Files to upload</Text>
            </Box>
            {filesToUpload.map((file) => (
              <Flex key={file.file.name} alignItems="center">
                <Box
                  display="flex"
                  width="48px"
                  height="48px"
                  bgColor={`${props.app.theme.options.primaryColor}23`}
                  marginRight={5}
                  justifyContent="center"
                  alignItems="center"
                  borderRadius="4px"
                  marginTop={2}
                >
                  {file.file.type.startsWith("image") ? (
                    <Image
                      alt="New image"
                      src={file.file["data"] ?? fallbackImg}
                      width="48px"
                      height="48px"
                      borderRadius="4px"
                    />
                  ) : file.file.type.startsWith("video") ? (
                    <Icon
                      as={Movie}
                      boxSize={7}
                      color={`${props.app.theme.options.primaryColor}`}
                    />
                  ) : file.file.type === "application/pdf" ? (
                    <Icon
                      as={FileBlank}
                      boxSize={7}
                      color={`${props.app.theme.options.primaryColor}`}
                    />
                  ) : (
                    <Icon
                      as={Upload}
                      boxSize={7}
                      color={`${props.app.theme.options.primaryColor}`}
                    />
                  )}
                </Box>
                <Box flex={1}>
                  <Text noOfLines={1}>{file.file.name}</Text>
                  <Text fontSize="sm" textColor="text.600">
                    {Math.ceil(file.file.size / 1024)} KB
                  </Text>
                </Box>
                <IconButton
                  aria-label="delete file"
                  icon={<Icon as={Delete} />}
                  variant="link"
                  color="#171717"
                  _hover={{ color: "#E03138", bg: "#FCEAEB" }}
                  width="48px"
                  height="48px"
                  onClick={() => {
                    setState((state) => ({
                      ...state,
                      files: Object.fromEntries(
                        Object.entries(state.files).filter(
                          ([key]) => key !== file.file.name
                        )
                      ),
                    }));
                  }}
                />
              </Flex>
            ))}
            {!!state.total && (
              <>
                <Progress
                  value={Math.round((state.loaded / state.total) * 100)}
                />
                <Text fontSize="sm" textColor="blackAlpha.600">
                  {Math.ceil(state.loaded / 1024)}/
                  {Math.ceil(state.total / 1024)} KB
                </Text>
              </>
            )}
          </Box>
        )}

        <Box
          {...getRootProps({ className: "dropzone" })}
          display="flex"
          flexDirection="column"
          alignItems="center"
          mt={2}
          cursor="pointer"
          border="1px"
          borderRadius="md"
          borderColor="rgb(226, 232, 240)"
          paddingY="10"
          bgColor="surface.900"
          style={{
            border: "1px solid rgb(226, 232, 240)",
            pointerEvents: isDisabled ? "none" : "auto",
            background: isDisabled && "#E7E7E7",
            color: isDisabled && "#A2A2A2",
          }}
        >
          <input
            {...getInputProps()}
            key={props.properties.data.inputID}
            name={props.properties.data.inputID}
            capture={
              props.properties.fileType === "camera"
                ? "user" || "environment"
                : undefined
            }
            data-test="file-picker-input"
          />
          <Icon
            as={Upload}
            boxSize={10}
            color={isDisabled ? "#A2A2A2" : "blue.500"}
            data-test="file-picker-input-icon"
          />
          <Text
            style={paddingSpace}
            noOfLines={1}
            align="center"
            w={{ base: "300px", md: "500px" }}
            color={isDisabled && "#A2A2A2"}
          >
            {placeholder}
          </Text>
          <Text fontSize="sm" color="text.600">
            Support for a single and bulk upload.
          </Text>
          <Text fontSize="sm" color="text.600">
            {maxFileSizeText}
          </Text>
        </Box>
      </FormControl>
      {!!validationMessage && (
        <Text fontSize="sm" color="red" mt="2">
          {validationMessage}
        </Text>
      )}
    </Box>
  );
};

export default MultipleFilePickerComponent;
